'use strict';

/**
 * Default error messages.
 *
 * @private
 */

var Messages = {
  // Type message
  type: function type(prop, ctx, _type) {
    return prop + ' must be of type ' + _type + '.';
  },


  // Required message
  required: function required(prop) {
    return prop + ' is required.';
  },


  // Match message
  match: function match(prop, ctx, regexp) {
    return prop + ' must match ' + regexp + '.';
  },


  // Length message
  length: function length(prop, ctx, _ref) {
    var min = _ref.min,
        max = _ref.max;

    if (min && max) {
      return prop + ' must have a length between ' + min + ' and ' + max + '.';
    }
    if (max) {
      return prop + ' must have a maximum length of ' + max + '.';
    }
    if (min) {
      return prop + ' must have a minimum length of ' + min + '.';
    }
  },


  // Enum message
  enum: function _enum(prop, ctx, enums) {
    var copy = enums.slice();
    var last = copy.pop();
    return prop + ' must be either ' + copy.join(', ') + ' or ' + last + '.';
  },


  // Default message
  default: function _default(prop) {
    return 'Validation failed for ' + prop + '.';
  }
};

module.exports = Messages;